@@ -4,10 +4,10 @@ import sys
 
 if getattr(sys, "pydebug", False):
     try:
-        from sipconfig_d import *
-        from sipconfig_d import _pkg_config, _default_macros
+        from sip4_tqt.sipconfig_d import *
+        from sip4_tqt.sipconfig_d import _pkg_config, _default_macros
     except ImportError as msg:
         raise ImportError('No module named sipconfig; package python-sip-tqt-dbg not installed')
 else:
-    from sipconfig_nd import *
-    from sipconfig_nd import _pkg_config, _default_macros
+    from sip4_tqt.sipconfig_nd import *
+    from sip4_tqt.sipconfig_nd import _pkg_config, _default_macros
