@@ -4,7 +4,7 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.0.10"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.0.12"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
 
@@ -22,3 +22,9 @@ else
   echo "Saving image to '${FILE}'"
   ${DOCKER} image save "${IMAGE}" | pigz >"${FILE}"
 fi
+
+# Strip 'localhost/' prefix from image tag
+if ! docker images | while read name tag blah; do echo "${name}:${tag}"; done | grep -q "^${IMAGE}$"; then
+  docker image tag "localhost/${IMAGE}" "${IMAGE}"
+  #docker image rm "localhost/${IMAGE}"
+fi
